import { http } from '@/utils/http';

/** 商店分页查询参数 */
export interface ShopQuery extends BasePageQuery {
  shopName?: string;
  corpid?: string;
  /** 归属类型（0-借还柜 1-固资通） */
  belongType?: number;
}

/** 商店DTO */
export interface ShopDTO {
  shopId: number;
  shopName: string;
  corpid?: string;
  /** 归属类型（0-借还柜 1-固资通） */
  belongType?: number;
}

/** 新增商店命令 */
export interface AddShopCommand {
  shopName: string;
  corpid: string;
  /** 归属类型（0-借还柜 1-固资通） */
  belongType?: number;
}

/** 更新商店命令 */
export interface UpdateShopCommand {
  corpid: string;
  shopId: number;
  shopName: string;
  /** 归属类型（0-借还柜 1-固资通） */
  belongType?: number;
}

/** 获取商店列表 */
export const getShopList = (params?: ShopQuery) => {
  return http.request<ResponseData<PageDTO<ShopDTO>>>('get', '/shop/shops', {
    params
  });
};

/** 新增商店 */
export const addShop = (data: AddShopCommand) => {
  return http.request<ResponseData<void>>('post', '/shop/shops', {
    data
  });
};

/** 修改商店 */
export const updateShop = (id: number, data: UpdateShopCommand) => {
  return http.request<ResponseData<void>>('put', `/shop/shops/${id}`, {
    data
  });
};

/** 删除商店 */
export const deleteShop = (ids: string) => {
  return http.request<ResponseData<void>>('delete', `/shop/shops/${ids}`);
};